Clustering
==========

.. autoclass:: igua.clustering.ClusteringStrategy
   :members:

.. autoclass:: igua.clustering.HierarchicalClustering(ClusteringStrategy)
   :special-members: __init__
   :members:
   :inherited-members:

.. autoclass:: igua.clustering.LinearClustering(ClusteringStrategy)
   :special-members: __init__
   :members:
   :inherited-members: